---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''

---

**Describe the bug**
<!-- NOTE: A clear and concise description of what the bug is. -->

**Steps to reproduce**
<!-- NOTE: Provide a simple set of steps to reproduce this bug. -->
1.
2.
3. 

**Backtrace**
```
If applicable, add the backtrace here.
```

**Context**
<!-- NOTE: Please give information about the wider context in which the bug has happened. -->
- OS: [e.g. Debian 12]
- Bob version [e.g. 0.24.0]
- Python version [e.g. 3.11.2]

<!-- TIP: If possible, provide a link to the used recipes. Otherwise some minimal example that reproduces the issue will be highly appreciated. -->
